@@ -29,7 +29,7 @@ Usage::
     list_nodes_paginator: ListNodesPaginator = client.get_paginator("list_nodes")
     ```
 """
-from mypy_boto3_kafka.client import KafkaClient as Client, KafkaClient
+from mypy_boto3_kafka.client import KafkaClient, KafkaClient as Client
 from mypy_boto3_kafka.paginator import (
     ListClusterOperationsPaginator,
     ListClustersPaginator,
